@@ -446,7 +446,7 @@ class line(plot):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=None,
                  # Title
@@ -535,7 +535,7 @@ class scatter(plot, color):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -636,7 +636,7 @@ class surface(plot, surf):
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  z_upper_resize_pad=0, z_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=None,
                  # Title
