@@ -229,7 +229,6 @@ class attributes:
                                                                                      self.y_lower_resize_pad,
                                                                                      self.y_bounds)
 
-
             if self.demo_pad_plot is True:
                 pad_x = 0.05 * (abs(self.x.max()) + abs(self.x.min()))
                 self.x_upper_resize_pad = pad_x
@@ -312,6 +311,17 @@ class attributes:
         self.ax.tick_params(axis='both', which='both', top=top, right=right, left=left, bottom=bottom)
 
     def method_ticks(self):
+        """
+        Defaults
+        """
+        if self.fine_tick_locations is True:
+            if not isinstance(self.x, type(None)):
+                self.custom_x_tick_locations = [self.x.min(), self.x.max()]
+            if not isinstance(self.y, type(None)):
+                self.custom_y_tick_locations = [self.y.min(), self.y.max()]
+        """
+        Implementation
+        """
         #   Tick-label distance
         self.ax.xaxis.set_tick_params(pad=0.1, direction='in')
         self.ax.yaxis.set_tick_params(pad=0.1, direction='in')
@@ -449,7 +459,7 @@ class plot(canvas, attributes):
             self.plt.savefig(self.filename, dpi=self.dpi)
 
     def method_show(self):
-        if self.more_subplots_left is not True:
+        if self.show is True:
             self.fig.tight_layout()
             self.plt.show()
         else:
@@ -553,7 +563,7 @@ class line(plot, std_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color='darkred', cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -568,7 +578,7 @@ class line(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -585,7 +595,7 @@ class line(plot, std_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -669,7 +679,7 @@ class scatter(plot, std_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color="C0", cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -684,7 +694,7 @@ class scatter(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -701,7 +711,7 @@ class scatter(plot, std_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -773,7 +783,7 @@ class heatmap(plot, df_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -788,7 +798,7 @@ class heatmap(plot, df_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -805,7 +815,7 @@ class heatmap(plot, df_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -882,7 +892,7 @@ class quiver(plot, std_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -897,7 +907,7 @@ class quiver(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -914,7 +924,7 @@ class quiver(plot, std_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -1009,7 +1019,7 @@ class streamline(plot, std_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -1024,7 +1034,7 @@ class streamline(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -1041,7 +1051,7 @@ class streamline(plot, std_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -1124,7 +1134,7 @@ class fill_area(plot, std_input):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
                  color=None, cmap='RdBu_r', alpha=None, norm=None,
                  # Title
@@ -1139,7 +1149,7 @@ class fill_area(plot, std_input):
                  tick_color=None, tick_label_pad=5,
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
-                 custom_x_tick_locations=None, custom_y_tick_locations=None,
+                 custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
                  tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
@@ -1156,7 +1166,7 @@ class fill_area(plot, std_input):
                  legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
                  # Suppress output
@@ -1225,12 +1235,10 @@ class fill_area(plot, std_input):
             self.x = np.arange(-6, 6, .01)
             self.y = MockData().boltzman(self.x, 0, 1)
             self.z = 1 - MockData().boltzman(self.x, 0.5, 1)
-            line(fig=self.fig, ax=self.ax, x=self.x, y=self.y, color='darkred', line_width=2,
-                 plot_label=None,
-                 more_subplots_left=True)
-            line(fig=self.fig, ax=self.ax, x=self.x, y=self.z, color='darkred', line_width=2,
-                 plot_label=None,
-                 more_subplots_left=True)
+            line(fig=self.fig, ax=self.ax, x=self.x, y=self.y, color='darkred', line_width=2, grid=self.grid,
+                 plot_label=None)
+            line(fig=self.fig, ax=self.ax, x=self.x, y=self.z, color='darkred', line_width=2, grid=self.grid,
+                 plot_label=None)
             self.below = True
 
 
